@@ -329,7 +329,7 @@ raise ValueError()
             firstlineno = 5
 
             def fullsource(self):
-                raise fail
+                return None
             fullsource = property(fullsource)
 
         class FakeFrame(object):
@@ -351,6 +351,8 @@ raise ValueError()
             
             def exconly(self, tryshort):
                 return "EXC"
+            def errisinstance(self, cls):
+                return False 
 
         excinfo = FakeExcinfo()
         class FakeRawTB(object):
