@@ -1,6 +1,6 @@
 import py
 import sys
-from py.__.path.svn.testing.svntestbase import CommonSvnTests, getrepowc
+from py.__.path.svn.testing.svntestbase import CommonSvnTests, getrepowc, getsvnbin
 from py.__.path.svn.wccommand import InfoSvnWCCommand, XMLWCStatus
 from py.__.path.svn.wccommand import parse_wcinfotime
 from py.__.path.svn import svncommon
@@ -22,8 +22,7 @@ else:
             return os.path.normpath(os.path.normcase(p))
 
 def setup_module(mod):
-    if py.path.local.sysfind('svn') is None:
-        py.test.skip("cannot test py.path.svn, 'svn' binary not found")
+    getsvnbin()
 
 class TestWCSvnCommandPath(CommonSvnTests):
     def setup_class(cls): 
@@ -367,22 +366,21 @@ class TestWCSvnCommandPath(CommonSvnTests):
     def test_commit_nonrecursive(self):
         root = self.root
         somedir = root.join('sampledir')
-        somefile = somedir.join('otherfile')
-        somefile.write('foo')
+        somedir.mkdir("subsubdir")
         somedir.propset('foo', 'bar')
         status = somedir.status()
         assert len(status.prop_modified) == 1
-        assert len(status.modified) == 1
+        assert len(status.added) == 1
 
         somedir.commit('non-recursive commit', rec=0)
         status = somedir.status()
         assert len(status.prop_modified) == 0
-        assert len(status.modified) == 1
+        assert len(status.added) == 1
 
         somedir.commit('recursive commit')
         status = somedir.status()
         assert len(status.prop_modified) == 0
-        assert len(status.modified) == 0
+        assert len(status.added) == 0
 
     def test_commit_return_value(self):
         root = self.root
