@@ -152,6 +152,48 @@ class TestCollect(suptest.InlineCollection):
         assert gencolitems[0].name == '[0]'
         assert gencolitems[0].obj.func_name == 'func1'
 
+    def test_generative_functions_with_explicit_names(self):
+        modcol = self.getmodulecol("""
+            def func1(arg, arg2): 
+                assert arg == arg2 
+
+            def test_gen(): 
+                yield "seventeen", func1, 17, 3*5
+                yield "fortytwo", func1, 42, 6*7
+        """)
+        colitems = modcol.collect()
+        assert len(colitems) == 1
+        gencol = colitems[0]
+        assert isinstance(gencol, py.test.collect.Generator)
+        gencolitems = gencol.collect()
+        assert len(gencolitems) == 2
+        assert isinstance(gencolitems[0], py.test.collect.Function)
+        assert isinstance(gencolitems[1], py.test.collect.Function)
+        assert gencolitems[0].name == "['seventeen']"
+        assert gencolitems[0].obj.func_name == 'func1'
+        assert gencolitems[1].name == "['fortytwo']"
+        assert gencolitems[1].obj.func_name == 'func1'        
+
+    def test_generative_methods_with_explicit_names(self): 
+        modcol = self.getmodulecol("""
+            def func1(arg, arg2): 
+                assert arg == arg2 
+            class TestGenMethods: 
+                def test_gen(self): 
+                    yield "m1", func1, 17, 3*5
+                    yield "m2", func1, 42, 6*7
+        """)
+        gencol = modcol.collect()[0].collect()[0].collect()[0]
+        assert isinstance(gencol, py.test.collect.Generator)
+        gencolitems = gencol.collect()
+        assert len(gencolitems) == 2
+        assert isinstance(gencolitems[0], py.test.collect.Function)
+        assert isinstance(gencolitems[1], py.test.collect.Function)
+        assert gencolitems[0].name == "['m1']"
+        assert gencolitems[0].obj.func_name == 'func1'
+        assert gencolitems[1].name == "['m2']"
+        assert gencolitems[1].obj.func_name == 'func1'        
+
     def test_module_assertion_setup(self):
         modcol = self.getmodulecol("pass")
         from py.__.magic import assertion
@@ -219,6 +261,28 @@ class TestCollect(suptest.InlineCollection):
         res2 = modcol.collect()
         assert res1 == [x.name for x in res2]
 
+    def test_allow_sane_sorting_for_decorators(self):
+        modcol = self.getmodulecol("""
+    def dec(f):
+        g = lambda: f(2)
+        g.place_as = f
+        return g
+
+
+    def test_a(y):
+        pass
+    test_a = dec(test_a)
+
+    def test_b(y):
+        pass
+    test_b = dec(test_b)
+    """)
+        colitems = modcol.collect()
+        assert len(colitems) == 2
+        f1, f2 = colitems
+        assert cmp(f2, f1) > 0
+
+
 class TestCustomConftests(suptest.InlineCollection):
     def test_extra_python_files_and_functions(self):
         self.makepyfile(conftest="""
@@ -427,29 +491,13 @@ class Testgenitems:
         ev = failures[0] 
         assert ev.outcome.longrepr.reprcrash.message.startswith("SyntaxError")
 
-    def test_skip_at_module_level(self):
-        self.tmp.ensure("test_module.py").write(py.code.Source("""
-            import py
-            py.test.skip('xxx')
-        """))
-        items, events = self._genitems()
-        funcs = [x for x in items if isinstance(x, event.ItemStart)]
-        assert not funcs 
-        assert not items 
-        l = [x for x in events 
-                if isinstance(x, event.CollectionReport)
-                   and x.colitem.name == 'test_module.py']
-        assert len(l) == 1
-        ev = l[0]
-        assert ev.skipped 
-
     def test_example_items1(self):
         self.tmp.ensure("test_example.py").write(py.code.Source('''
-            def test_one():
+            def testone():
                 pass
 
             class TestX:
-                def test_method_one(self):
+                def testmethod_one(self):
                     pass
 
             class TestY(TestX):
@@ -457,17 +505,17 @@ class Testgenitems:
         '''))
         items, events = self._genitems()
         assert len(items) == 3
-        assert items[0].name == 'test_one'
-        assert items[1].name == 'test_method_one'
-        assert items[2].name == 'test_method_one'
+        assert items[0].name == 'testone'
+        assert items[1].name == 'testmethod_one'
+        assert items[2].name == 'testmethod_one'
 
         # let's also test getmodpath here
-        assert items[0].getmodpath() == "test_one"
-        assert items[1].getmodpath() == "TestX.test_method_one"
-        assert items[2].getmodpath() == "TestY.test_method_one"
+        assert items[0].getmodpath() == "testone"
+        assert items[1].getmodpath() == "TestX.testmethod_one"
+        assert items[2].getmodpath() == "TestY.testmethod_one"
 
         s = items[0].getmodpath(stopatmodule=False)
-        assert s == "test_example_items1.test_example.test_one"
+        assert s == "test_example_items1.test_example.testone"
         print s
 
     def test_collect_doctest_files_with_test_prefix(self):
